config = {}


def set_env(env):
    config["MLFLOW_TRACKING_URI"] = 


    "MLFLOW_TRACKING_URI": "http://35.238.159.24:5000",
    "AWS_ACCESS_KEY_ID": "ZPmLIAFFe3zNafR5",
    "AWS_SECRET_ACCESS_KEY": "lJXFYMz9ZeyoH43uDJJFDqW9uUx5lhsV",
    "AWS_DEFAULT_REGION": "us-east-1",
    "BUCKET_NAME": "mlflow-bucket",
    "BUCKET_FOLDER": "mlflow",
    "S3_ENDPOINT_URL": "=localhost:9000",
    "IAM_URI": "https://iam-dhuo-data-stg.br.engineering"
}



# MLFLOW_TRACKING_URI=https://mlflow-dhuo-data-prd.br.engineering








def set_env(env):
    if env == 'stg':
        ENV =


# utils.py

import base64


def encode(message: str):
    message_bytes = message.encode('ascii')
    base64_bytes = base64.b64encode(message_bytes)
    base64_message = base64_bytes.decode('ascii')

    return base64_message


def decode(base64_message: str):
    base64_bytes = base64_message.encode('ascii')
    message_bytes = base64.b64decode(base64_bytes)
    message = message_bytes.decode('ascii')
    return message




# cli.py

import logging
import click
import os
from dhuolib.auth.login import do_login
from dotenv import load_dotenv

load_dotenv() 


@click.group()
def main():
    """Library for data science on DHuO Data"""


@main.command()
@click.option('--email', prompt=True, help='Your DHuO Data email')
@click.option('--password', prompt=True, help='Your DHuO Data password', 
            hide_input=True, confirmation_prompt=True)
def login(email, password):
    """Provides user authentication"""

    click.echo("Efetuando login...")

    try: 
        do_login(email, password)

        click.echo(f"Seja bem-vindo ao DHuO Data {email}")

    except Exception as e:
        logging.exception("Logon error")        


@main.command()
def create_project():
    """Create Machine Learning project"""


@main.command()
def list_projects():
    """List Machine Learning """


@main.command()
def status():
    """Show current status"""    


@main.command()
def get_project():
    """Get project"""    


@main.command()
def show_info():
    """Show environment info"""

    click.echo("IAM_URI\t" + os.getenv("IAM_URI"))



from setuptools import setup, find_packages


def readme():
    with open('README.md') as f:
        return f.read()
    

REQUIREMENTS = ['click', 
                'requests>=2.28',
                'pandas==1.5.3',
                'mlflow[extras]==2.1',
                'python-dotenv==0.21',
                'minio==7.1',
                'scikit-learn==1.2']

SETUP_REQUIRES = ['flake8', 'pytest-runner']


setup(
    name='dhuolib',
    version='0.1.1',
    long_description=readme(),
    long_description_content_type="text/markdown",
    author='Antonio Carlos de Lima Junior',
    author_email='antonio.lima@engdb.com.br',
    url='https://gitlab.engdb.com.br/dhuo-plat/dhuo-data/data-science/dhuolib',
    packages=find_packages(include=['dhuolib', 'dhuolib.*']),
    install_requires=REQUIREMENTS,
    setup_requires=SETUP_REQUIRES,
    tests_require=['pytest'],
    entry_points={
      'console_scripts': ['dh = dhuolib.cli:main']
    },
    classifiers=[               
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 3',        
        'Operating System :: OS Independent',
        'Natural Language :: Portuguese (Brazilian)',
        'Natural Language :: English',

      ],
    keywords='datascience datapipeline mlops',
    license='MIT',
)



# persistence.py

import configparser
import os

from dhuolib.utils.utils import decode, encode


LOCAL_DHUO_CONFIG = ".dhuo"


class Persistence():
    
    def __init__(self):
        self.config = configparser.ConfigParser()
        self.username = None
        self.password = None
        self.workspace = None
        self.project = None
        self.workspace_id = None
        self.experiment_id = None
        
        if not os.path.isfile(LOCAL_DHUO_CONFIG):
            self.init()


    def init(self ):
        data = {"default": 
                    {"username": "",
                     "password": "",
                     "project": "",
                     "workspace": "",
                     "workspace_id": "",
                     "experiment_id": "",
                     }
        }

        self.save(data)


    def save(self, data):
        self.config.read_dict(data)
        with open(LOCAL_DHUO_CONFIG, 'w') as configfile:
            self.config.write(configfile)


    def save_username(self, username):
        self.config.read(LOCAL_DHUO_CONFIG)
        self.config["default"]["username"] = username
        with open(LOCAL_DHUO_CONFIG, 'w') as configfile:
            self.config.write(configfile)  


    def save_password(self, password):
        self.config.read(LOCAL_DHUO_CONFIG)
        self.config["default"]["password"] = encode(password)
        with open(LOCAL_DHUO_CONFIG, 'w') as configfile:
            self.config.write(configfile)              


    def save_project(self, project):
        self.config.read(LOCAL_DHUO_CONFIG)
        self.config["default"]["project"] = project
        with open(LOCAL_DHUO_CONFIG, 'w') as configfile:
            self.config.write(configfile)  


    def save_workspace(self, workspace):
        self.config.read(LOCAL_DHUO_CONFIG)
        self.config["default"]["workspace"] = workspace
        with open(LOCAL_DHUO_CONFIG, 'w') as configfile:
            self.config.write(configfile)  


    def save_workspace_id(self, workspace_id):
        self.config.read(LOCAL_DHUO_CONFIG)
        self.config["default"]["workspace_id"] = workspace_id
        with open(LOCAL_DHUO_CONFIG, 'w') as configfile:
            self.config.write(configfile)              


    def save_experiment_id(self, experiment_id):
        self.config.read(LOCAL_DHUO_CONFIG)
        self.config["default"]["experiment_id"] = experiment_id
        with open(LOCAL_DHUO_CONFIG, 'w') as configfile:
            self.config.write(configfile)  


    def get_username(self):
        dict = self.to_dict()
        return dict["default"]["username"]
    

    def get_password(self):
        dict = self.to_dict()
        return dict["default"]["password"]
    

    def get_workspace(self):
        dict = self.to_dict()
        return dict["default"]["workspace"]
    
    
    def get_workspace_id(self):
        dict = self.to_dict()
        return dict["default"]["workspace_id"]


    def get_project(self):
        dict = self.to_dict()
        return dict["default"]["project"]
    

    def get_experiment_id(self):
        dict = self.to_dict()
        return dict["default"]["experiment_id"]    
    

    def to_dict(self):
        self.config.read(LOCAL_DHUO_CONFIG)
        return  {
            "default": {
                "username": self.config["default"]["username"],
                "password": decode(self.config["default"]["password"]),
                "project": self.config["default"]["project"],
                "workspace": self.config["default"]["workspace"],
                "workspace_id": self.config["default"]["workspace_id"],
                "experiment_id": self.config["default"]["experiment_id"]
            }
        }
    
    
    def reset_and_get_credentials(self):
        self.save_experiment_id("")
        self.save_project("")
        self.save_workspace("")
        self.save_workspace_id("")

        return self.get_username(), self.get_password()


persistence = Persistence()


if __name__ == "__main__":
    
    persistence.save_username("antonioclj.ac@gmail.com")
    persistence.save_password("Pwd@9051")
    persistence.save_project("projeto-123")
    persistence.save_workspace("wks-abc")
    persistence.save_workspace_id("wks-123")
    persistence.save_experiment_id("exp-123")

    print(persistence.to_dict())
    print(persistence.get_username())
    print(persistence.get_password())
    print(persistence.get_project())
    print(persistence.get_workspace())
    print(persistence.get_workspace_id())
    print(persistence.get_experiment_id())
    
    print(persistence.reset_and_get_credentials())
